From bbdadcca8732bb57749ffda998ab2e22e7fb8035 Mon Sep 17 00:00:00 2001
From: Sergey Fedorov <barracuda@macos-powerpc.org>
Date: Sun, 4 Aug 2024 01:39:51 +0800
Subject: [PATCH 11/21] os_apple.m etc.: fix syntax for plists

---
 CMakeLists.txt                                |  2 +-
 src/detection/cursor/cursor_apple.m           | 10 +------
 src/detection/os/os_apple.m                   | 22 ++++++---------
 .../terminalfont/terminalfont_apple.m         | 28 ++++---------------
 src/detection/wmtheme/wmtheme_apple.m         | 10 +------
 5 files changed, 18 insertions(+), 54 deletions(-)

diff --git a/CMakeLists.txt b/CMakeLists.txt
index 7efcfde8..48b09289 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -647,7 +647,7 @@ elseif(APPLE)
         src/detection/cpu/cpu_apple.c
         src/detection/cpucache/cpucache_apple.c
         src/detection/cpuusage/cpuusage_apple.c
-        src/detection/cursor/cursor_apple.m
+        src/detection/cursor/cursor_nosupport.c
         src/detection/disk/disk_bsd.c
         src/detection/dns/dns_linux.c
         src/detection/physicaldisk/physicaldisk_apple.c
diff --git a/src/detection/cursor/cursor_apple.m b/src/detection/cursor/cursor_apple.m
index 40d4b90c..c71c440a 100644
--- a/src/detection/cursor/cursor_apple.m
+++ b/src/detection/cursor/cursor_apple.m
@@ -19,15 +19,7 @@ static void appendColor(FFstrbuf* str, NSDictionary* color)
 
 void ffDetectCursor(FFCursorResult* result)
 {
-    NSError* error;
-    NSString* fileName = [NSString stringWithFormat:@"file://%s/Library/Preferences/com.apple.universalaccess.plist", instance.state.platform.homeDir.chars];
-    NSDictionary* dict = [NSDictionary dictionaryWithContentsOfURL:[NSURL URLWithString:fileName]
-                                       error:&error];
-    if(error)
-    {
-        ffStrbufAppendS(&result->error, error.localizedDescription.UTF8String);
-        return;
-    }
+    NSDictionary* dict = [NSDictionary dictionaryWithContentsOfFile:[NSHomeDirectory() stringByAppendingPathComponent:@"/Library/Preferences/com.apple.universalaccess.plist"]];
 
     NSDictionary* color;
 
diff --git a/src/detection/os/os_apple.m b/src/detection/os/os_apple.m
index 5a8ef621..dc606c92 100644
--- a/src/detection/os/os_apple.m
+++ b/src/detection/os/os_apple.m
@@ -6,25 +6,21 @@
 
 #include <stdlib.h>
 #include <string.h>
-#import <Foundation/Foundation.h>
+#include <Foundation/Foundation.h>
 
 static void parseSystemVersion(FFOSResult* os)
 {
-    NSError* error;
-    NSString* fileName = @"file:///System/Library/CoreServices/SystemVersion.plist";
-    NSDictionary* dict = [NSDictionary dictionaryWithContentsOfURL:[NSURL URLWithString:fileName]
-                                       error:&error];
-    if(error)
-        return;
+    NSDictionary* dict = [NSDictionary dictionaryWithContentsOfFile:
+        @"/System/Library/CoreServices/SystemVersion.plist"];
 
     NSString* value;
 
-    if((value = [dict valueForKey:@"ProductName"]))
-        ffStrbufInitS(&os->name, value.UTF8String);
-    if((value = [dict valueForKey:@"ProductUserVisibleVersion"]))
-        ffStrbufInitS(&os->version, value.UTF8String);
-    if((value = [dict valueForKey:@"ProductBuildVersion"]))
-        ffStrbufInitS(&os->buildID, value.UTF8String);
+    if ((value = [dict objectForKey:@"ProductName"]))
+        ffStrbufInitS(&os->name, [value UTF8String]);
+    if ((value = [dict objectForKey:@"ProductUserVisibleVersion"]))
+        ffStrbufInitS(&os->version, [value UTF8String]);
+    if ((value = [dict objectForKey:@"ProductBuildVersion"]))
+        ffStrbufInitS(&os->buildID, [value UTF8String]);
 }
 
 static bool detectOSCodeName(FFOSResult* os)
diff --git a/src/detection/terminalfont/terminalfont_apple.m b/src/detection/terminalfont/terminalfont_apple.m
index 7d6aca28..96917199 100644
--- a/src/detection/terminalfont/terminalfont_apple.m
+++ b/src/detection/terminalfont/terminalfont_apple.m
@@ -16,19 +16,11 @@ static void detectIterm2(FFTerminalFontResult* terminalFont)
         return;
     }
 
-    NSError* error;
-    NSString* fileName = [NSString stringWithFormat:@"file://%s/Library/Preferences/com.googlecode.iterm2.plist", instance.state.platform.homeDir.chars];
-    NSDictionary* dict = [NSDictionary dictionaryWithContentsOfURL:[NSURL URLWithString:fileName]
-                                       error:&error];
-    if(error)
-    {
-        ffStrbufAppendS(&terminalFont->error, error.localizedDescription.UTF8String);
-        return;
-    }
+    NSDictionary* dict = [NSDictionary dictionaryWithContentsOfFile:[NSHomeDirectory() stringByAppendingPathComponent:@"/Library/Preferences/com.googlecode.iterm2.plist"]];
 
     for(NSDictionary* bookmark in [dict valueForKey:@"New Bookmarks"])
     {
-        if(![[bookmark valueForKey:@"Name"] isEqualToString:@(profile)])
+        if(![[bookmark valueForKey:@"Name"] isEqualToString:[NSString stringWithUTF8String:profile]])
             continue;
 
         NSString* normalFont = [bookmark valueForKey:@"Normal Font"];
@@ -37,14 +29,14 @@ static void detectIterm2(FFTerminalFontResult* terminalFont)
             ffStrbufAppendF(&terminalFont->error, "`Normal Font` key in profile `%s` doesn't exist", profile);
             return;
         }
-        ffFontInitWithSpace(&terminalFont->font, normalFont.UTF8String);
+        ffFontInitWithSpace(&terminalFont->font, [normalFont UTF8String]);
 
         NSNumber* useNonAsciiFont = [bookmark valueForKey:@"Use Non-ASCII Font"];
-        if(useNonAsciiFont.boolValue)
+        if([useNonAsciiFont boolValue])
         {
             NSString* nonAsciiFont = [bookmark valueForKey:@"Non Ascii Font"];
             if (nonAsciiFont)
-                ffFontInitWithSpace(&terminalFont->fallback, nonAsciiFont.UTF8String);
+                ffFontInitWithSpace(&terminalFont->fallback, [nonAsciiFont UTF8String]);
         }
         return;
     }
@@ -68,15 +60,7 @@ static void detectAppleTerminal(FFTerminalFontResult* terminalFont)
 
 static void detectWarpTerminal(FFTerminalFontResult* terminalFont)
 {
-    NSError* error;
-    NSString* fileName = [NSString stringWithFormat:@"file://%s/Library/Preferences/dev.warp.Warp-Stable.plist", instance.state.platform.homeDir.chars];
-    NSDictionary* dict = [NSDictionary dictionaryWithContentsOfURL:[NSURL URLWithString:fileName]
-                                       error:&error];
-    if(error)
-    {
-        ffStrbufAppendS(&terminalFont->error, error.localizedDescription.UTF8String);
-        return;
-    }
+    NSDictionary* dict = [NSDictionary dictionaryWithContentsOfFile:[NSHomeDirectory() stringByAppendingPathComponent:@"/Library/Preferences/dev.warp.Warp-Stable.plist"]];
 
     NSString* fontName = [dict valueForKey:@"FontName"];
     if(!fontName)
diff --git a/src/detection/wmtheme/wmtheme_apple.m b/src/detection/wmtheme/wmtheme_apple.m
index 08810b6c..b78acac0 100644
--- a/src/detection/wmtheme/wmtheme_apple.m
+++ b/src/detection/wmtheme/wmtheme_apple.m
@@ -5,15 +5,7 @@
 
 bool ffDetectWmTheme(FFstrbuf* themeOrError)
 {
-    NSError* error;
-    NSString* fileName = [NSString stringWithFormat:@"file://%s/Library/Preferences/.GlobalPreferences.plist", instance.state.platform.homeDir.chars];
-    NSDictionary* dict = [NSDictionary dictionaryWithContentsOfURL:[NSURL URLWithString:fileName]
-                                       error:&error];
-    if(error)
-    {
-        ffStrbufAppendS(themeOrError, error.localizedDescription.UTF8String);
-        return false;
-    }
+    NSDictionary* dict = [NSDictionary dictionaryWithContentsOfFile:[NSHomeDirectory() stringByAppendingPathComponent:@"/Library/Preferences/.GlobalPreferences.plist"]];
 
     NSNumber* wmThemeColor = [dict valueForKey:@"AppleAccentColor"];
     if(!wmThemeColor)
-- 
2.46.0

